# LaTeX2HTML 96.1-h (September 30, 1996)
# Associate internals original text with physical files.

$key = q/sectransfer/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secmigrain/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/figgeneral/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/figcheck/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/figdate/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/figcbbrctcl/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secnormalinstall/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secviewcat/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/sectutedit/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secimpquick/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secediting/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";
$key = q/secinstalllatest/;
$ref_files{$key} = "$dir".q|cbb-man.html|; 
$noresave{$key} = "$nosave";

1;

